@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Rinci::Wrap;
 
-our $DATE = '2015-09-26'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2016-01-14'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -152,7 +152,7 @@ sub munge_file {
             $self->log_debug("Skipped sub '$sub_name' (not listed in include_func) ...");
             next;
         }
-        my $res = wrap_sub(
+        my %wrap_args = (
             %{ $wrap_args },
             %{ $metas->{$_}{"x.dist.zilla.plugin.rinci.wrap.wrap_args"} // {} },
             sub_name  => "$pkg_name\::$sub_name",
@@ -161,6 +161,7 @@ sub munge_file {
             _extra_sah_compiler_args => {comment=>0},
             embed=>1,
         );
+        my $res = wrap_sub(%wrap_args);
         unless ($res->[0] == 200) {
             $self->log_fatal("Can't wrap $sub_name: $res->[0] - $res->[1]");
             return;
@@ -274,18 +275,15 @@ sub munge_file {
                 my $indent = $1;
 
                 # remove comment that might interfere with preamble adding
-                $line =~ s/(.+)#.*/$1/;
+                $line =~ s/(.+?)#.*/$1/;
 
                 # put preamble code
                 $line = "$indent\n$indent# [Rinci::Wrap] BEGIN preamble\n$line" if $self->debug;
                 my $preamble = $wres{$sub_name}{source}{preamble};
-                if ($has_postamble) {
-                    # remove comment that might interfere with adding
-                    $preamble =~ s/(.+)#.*/$1/;
-                    $preamble .= $indent . '$_w_res = do {';
-                }
                 $line =~ s/\n//;
-                $line .= " " . $self->_squish_code($preamble) . $sig . "\n";
+                $line .= " " . $self->_squish_code($preamble) .
+                    ($self->debug ? "\n$indent" : "") . '$_w_res = do {' .
+                    $sig . "\n";
                 $line = "$line\n$indent# [Rinci::Wrap] END preamble\n" if $self->debug;
                 $has_put_preamble = 1;
                 next LINE;
@@ -349,7 +347,7 @@ Dist::Zilla::Plugin::Rinci::Wrap - Insert wrapper-generated code
 
 =head1 VERSION
 
-This document describes version 0.11 of Dist::Zilla::Plugin::Rinci::Wrap (from Perl distribution Dist-Zilla-Plugin-Rinci-Wrap), released on 2015-09-26.
+This document describes version 0.12 of Dist::Zilla::Plugin::Rinci::Wrap (from Perl distribution Dist-Zilla-Plugin-Rinci-Wrap), released on 2016-01-14.
 
 =head1 SYNOPSIS
 
@@ -535,7 +533,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-Rinci-Wrap>.
+Source repository is at L<https://github.com/sharyanto/perl-Dist-Zilla-Plugin-Rinci-Wrap>.
 
 =head1 BUGS
 
@@ -551,7 +549,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
